EndOfInput class final

Reached end of input when more was expected.

Inheritance

Constructors

EndOfInput(String expected, Location location)
Creates an end-of-input error.

Properties

expected String
What was expected at end of input.
final
hashCode int
The hash code for this object.
no setterinherited
location Location
Where in the input this error occurred.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited