IncrementalStrategy enum

Which tier of incrementalParse produced the result.

Inheritance
Available extensions

Values

tokenLevel → const IncrementalStrategy

Tier 1 — a single token's text was edited in place.

blockLevel → const IncrementalStrategy

Tier 2 — a reparsable region was reparsed and spliced.

fullReparse → const IncrementalStrategy

Tier 3 — the whole document was reparsed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IncrementalStrategy>
A constant List of the values in this enum, in order of their declaration.