NotFollowedBy<A> class final

Succeeds only if parser would fail (negative lookahead).

Inheritance
Available extensions

Constructors

NotFollowedBy(Parser<ParseError, A> parser)
Creates a negative lookahead parser.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSimple → bool
True if this parser cannot consume input on failure. Used to skip save/restore in Many/Choice/Or loops.
no setteroverride
lookAhead → Parser<ParseError, A>

Available on Parser<ParseError, A>, provided by the ParseErrorOps extension

Run this parser but consume no input on success (peek).
no setter
notFollowedBy → Parser<ParseError, void>

Available on Parser<ParseError, A>, provided by the ParseErrorOps extension

Succeed (consuming nothing) if this parser would fail at the current position.
no setter
parser → Parser<ParseError, A>
The parser that must not match.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

expect(String message) → Parser<ParseError, A>

Available on Parser<ParseError, A>, provided by the ParseErrorOps extension

Replace the error message with message on failure.
named(String name) → Parser<ParseError, A>

Available on Parser<ParseError, A>, provided by the ParseErrorOps extension

Add name to expected-set in error messages on failure.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited