Satisfy class final

Matches a single character satisfying pred.

Inheritance

Constructors

Satisfy(bool pred(String), String expected)
Creates a character parser with pred and expected label.
const

Properties

expected String
Description shown in error messages when the predicate fails.
final
hashCode int
The hash code for this object.
no setterinherited
isSimple bool
True if this parser cannot consume input on failure. Used to skip save/restore in Many/Choice/Or loops.
no setteroverride
pred bool Function(String)
The predicate the character must satisfy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited