Success<E, A> class final

Parse succeeded with no errors.

Inheritance
Available extensions

Constructors

Success(A value, int consumed)
Creates a successful result.
const

Properties

consumed int
Number of input characters consumed.
final
errors List<E>

Available on Result<E, A>, provided by the ResultOps extension

Errors from any case. Empty for Success.
no setter
hashCode int
The hash code for this object.
no setterinherited
isFailure bool

Available on Result<E, A>, provided by the ResultOps extension

True if this is a Failure.
no setter
isPartial bool

Available on Result<E, A>, provided by the ResultOps extension

True if this is a Partial.
no setter
isSuccess bool

Available on Result<E, A>, provided by the ResultOps extension

True if this is a Success.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → A
The parsed value.
final
valueOrNull → A?

Available on Result<E, A>, provided by the ResultOps extension

The value if Success or Partial, null if Failure.
no setter

Methods

map<B>(B f(A)) Result<E, B>

Available on Result<E, A>, provided by the ResultOps extension

Transforms the value, preserving errors and consumed count.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited