IncrementalConfig class final
Incremental-parse tuning.
Constructors
- IncrementalConfig({int minReparseSize = 50})
-
Creates a config.
minReparseSizedefaults to 50, matching rumil-scala.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minReparseSize → int
-
If the would-be reparse region is within minReparseSize characters of
the whole document, do a full reparse instead — the incremental
bookkeeping isn't worth it for near-whole-document edits.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited