InfixRight<A> class
final
Right-associative infix: a op b op c → a op (b op c).
- Inheritance
-
- Object
- PrattOperator<
A> - InfixRight
Constructors
-
InfixRight(Parser<
ParseError, Object?> symbol, int bp, A fn(A, A)) -
Creates a right-associative infix operator descriptor.
const
Properties
- bp → int
-
Binding power — higher means tighter.
final
- fn → A Function(A, A)
-
Combines LHS and RHS into the result.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
symbol
→ Parser<
ParseError, Object?> -
The parser recognizing this operator's symbol.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited