NotFollowedBy<A> class
final
Succeeds only if parser would fail (negative lookahead).
- Inheritance
-
- Object
- Parser<
ParseError, void> - NotFollowedBy
- Available extensions
Constructors
-
NotFollowedBy(Parser<
ParseError, A> parser) -
Creates a negative lookahead parser.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSimple → bool
-
True if this parser cannot consume input on failure.
Used to skip save/restore in Many/Choice/Or loops.
no setteroverride
-
lookAhead
→ Parser<
ParseError, A> -
Available on Parser<
Run this parser but consume no input on success (peek).ParseError, A> , provided by the ParseErrorOps extensionno setter -
notFollowedBy
→ Parser<
ParseError, void> -
Available on Parser<
Succeed (consuming nothing) if this parser would fail at the current position.ParseError, A> , provided by the ParseErrorOps extensionno setter -
parser
→ Parser<
ParseError, A> -
The parser that must not match.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
expect(
String message) → Parser< ParseError, A> -
Available on Parser<
Replace the error message withParseError, A> , provided by the ParseErrorOps extensionmessageon failure. -
named(
String name) → Parser< ParseError, A> -
Available on Parser<
AddParseError, A> , provided by the ParseErrorOps extensionnameto expected-set in error messages on failure. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited