Partial<E, A> class
final
Parse succeeded but accumulated errors (resilient parsing).
Constructors
Properties
- consumed → int
-
Number of input characters consumed.
final
-
errors
→ List<
E> -
Materialized errors (evaluated once from errorThunk).
no setter
-
errors
→ List<
E> -
Available on Result<
Errors from any case. Empty for Success.E, A> , provided by the ResultOps extensionno setter -
errorThunk
→ List<
E> Function() -
Lazy error thunk, evaluated on first access of errors.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFailure → bool
-
Available on Result<
True if this is a Failure.E, A> , provided by the ResultOps extensionno setter - isPartial → bool
-
Available on Result<
True if this is a Partial.E, A> , provided by the ResultOps extensionno setter - isSuccess → bool
-
Available on Result<
True if this is a Success.E, A> , provided by the ResultOps extensionno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → A
-
The parsed value.
final
- valueOrNull → A?
-
Available on Result<
The value if Success or Partial,E, A> , provided by the ResultOps extensionnullif Failure.no setter
Methods
-
map<
B> (B f(A)) → Result< E, B> -
Available on Result<
Transforms the value, preserving errors and consumed count.E, A> , provided by the ResultOps extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited